.. dowhy documentation master file, created by
   sphinx-quickstart on Tue Mar 13 14:48:10 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Introducing DoWhy
   
   readme

.. toctree::
   :maxdepth: 2
   :caption: Quick-Start Tutorial

   ./example_notebooks/tutorial-causalinference-machinelearning-using-dowhy-econml

.. toctree::
   :maxdepth: 2
   :caption: Starter Notebooks
   
   example_notebooks/nb_index

.. toctree::
   :maxdepth: 2
   :caption: Case Study Notebooks
   
   example_notebooks/nb_casestudies_index

.. toctree::
   :maxdepth: 2
   :caption: Advanced Notebooks
   
   example_notebooks/nb_advanced_index

.. toctree::
   :maxdepth: 2
   :caption: Package

   code_repo
   dowhy

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
